@@ -8,8 +8,19 @@
 ## 2016-10-28 NOT YET userdist may be session-specific
 ## 2017-02-06 updated for telemetry (completing job started last month)
 ## 2020-08-31 ORL, centroids
+## 2021-05-18 sortorder
 ############################################################################################
 
+getID <- function (det, capthist) {
+    if (all(det %in% .localstuff$polydetectors)) {
+        ID <- animalID(capthist, names = TRUE, sortorder = "ksn")
+    }
+    else {
+        ID <- animalID(capthist, names = TRUE, sortorder = "snk")
+    }
+    factor(ID, levels = rownames(capthist))
+}
+
 dbar <- function (capthist, userdist = NULL, mask = NULL) {
     if (inherits (capthist, 'list')) {
         lapply(capthist, dbar, userdist, mask)   ## recursive
@@ -26,7 +37,7 @@ dbar <- function (capthist, userdist = NULL, mask = NULL) {
         if (nrow(capthist) < 1) return(NA)
         traps <- traps(capthist)
         det <- expanddet(capthist)
-        IDfactor <- factor(animalID(capthist, names = TRUE), levels = rownames(capthist))
+        IDfactor <- getID(det, capthist)
         ## 2014-09-01
         ## NOT USING PARAMETERS noneuc ETC
         distmat <- valid.userdist(userdist, det, traps, traps, mask )
@@ -87,8 +98,6 @@ moves <- function (capthist, userdist = NULL, mask = NULL, names = FALSE) {
             sqrt(diff(xy$x)^2 + diff(xy$y)^2)
         }
         traps <- traps(capthist)
-        IDfactor <- factor(animalID(capthist, names = TRUE), levels = rownames(capthist))
-        
         if (is.null(traps)) {
             ## return empty vector if nonspatial 2019-04-04
             nam <- rownames(capthist)
@@ -97,6 +106,7 @@ moves <- function (capthist, userdist = NULL, mask = NULL, names = FALSE) {
         }
         else {
             det <- expanddet(capthist)
+            IDfactor <- getID(det, capthist)
             distmat <- valid.userdist(userdist, det, traps, traps, mask)
             if (!all(det %in% .localstuff$individualdetectors))
                 stop ("require individual detector type for moves")
@@ -160,8 +170,7 @@ ARL <- function (capthist, min.recapt = 1, plt = FALSE, full = FALSE, userdist =
         if (nrow(capthist) < 1) return(NA)
         traps <- traps(capthist)
         det <- expanddet(capthist)
-        IDfactor <- factor(animalID(capthist, names = TRUE), levels = rownames(capthist))
-        
+        IDfactor <- getID(det, capthist)
         if (!all(det %in% .localstuff$individualdetectors))
             stop ("require individual detector type for ARL")
         distmat <- valid.userdist(userdist, det, traps, traps, mask )
@@ -250,8 +259,7 @@ MMDM <- function (capthist, min.recapt = 1, full = FALSE, userdist = NULL, mask
         if (nrow(capthist) < 1) return(NA)
         traps <- traps(capthist)
         det <- expanddet(capthist)
-        IDfactor <- factor(animalID(capthist, names = TRUE), levels = rownames(capthist))
-        
+        IDfactor <- getID(det, capthist)
         distmat <- valid.userdist(userdist, det, traps, traps, mask )
         if (!all(det %in% .localstuff$individualdetectors))
             stop ("require individual detector type for MMDM")
@@ -329,11 +337,10 @@ RPSV <- function (capthist, CC = FALSE)
         if (nrow(capthist) < 1) return(NA)
         traps <- traps(capthist)
         det <- expanddet(capthist)
-        IDfactor <- factor(animalID(capthist, names = TRUE), levels = rownames(capthist))
-        
         if (!all(det %in% .localstuff$individualdetectors))
             stop ("require individual detector type for RPSV")
-     
+        IDfactor <- getID(det, capthist)
+        
         if (all(det %in% 'telemetry')) {
             lxy <- telemetryxy(capthist)
             if (is.null(lxy))
@@ -428,8 +435,7 @@ ORL <- function (capthist, userdist = NULL, mask = NULL) {
             stop ("require individual detector type for ARL")
         distmat <- valid.userdist(userdist, det, traps, traps, mask )
         prox  <- length(dim(capthist)) > 2
-
-        IDfactor <- factor(animalID(capthist, names = TRUE), levels = rownames(capthist))
+        IDfactor <- getID(det, capthist)
         
         if (all(det %in% 'telemetry')) {
             lxy <- telemetryxy(capthist)
@@ -501,11 +507,13 @@ centroids <- function (capthist) {
         if (nrow(capthist) < 1) return(NA)
         traps <- traps(capthist)
         det <- expanddet(capthist)
+        IDfactor <- getID(det, capthist)
+        
         if (!all(det %in% .localstuff$individualdetectors))
             stop ("require individual detector type for centres")
         
         if (all(det %in% 'telemetry')) {
-            lxy <- telemetryxy(capthist)
+            lxy <- telemetryxy(capthist)  ## already list by animal
             if (is.null(lxy))
                 temp <- NA
             else {
@@ -517,8 +525,7 @@ centroids <- function (capthist) {
             if (is.null(xy(capthist)))
                 temp <- NA
             else {
-                ID <- animalID(capthist, names = FALSE)
-                lxy <- split ( xy(capthist), ID)
+                lxy <- split ( xy(capthist), IDfactor)
                 temp <- lapply (lxy, centresxy)
             }
         }
@@ -528,8 +535,8 @@ centroids <- function (capthist) {
                     occasions = det != 'telemetry', 
                     traps = 1:(nrow(traps(capthist)-1)))
             }
-            ID <- animalID(capthist, names = FALSE)
-            w <- split(trap(capthist, names = FALSE), ID)
+            IDfactor <- factor(animalID(capthist, names = FALSE))
+            w <- split(trap(capthist, names = FALSE), IDfactor)
             temp <- lapply(w,centresx)
         }
         out <- do.call(rbind, temp)
